@@ -1,17 +1,16 @@
-import json
 import logging
 from uuid import UUID
 from flask import (
     Blueprint,
     g,
-    make_response,
     request
 )
 from flask.json import jsonify
 from argus.backend.controller.notification_api import bp as notifications_bp
 from argus.backend.service.argus_service import ArgusService
 from argus.backend.controller.auth import login_required
-from argus.db.models import UserOauthToken
+from argus.backend.service.stats import ReleaseStatsCollector
+from argus.db.models import ArgusRelease, ArgusReleaseGroup, ArgusReleaseGroupTest, UserOauthToken
 
 # pylint: disable=broad-except
 
@@ -21,7 +20,7 @@ LOGGER = logging.getLogger(__name__)
 
 
 @bp.route("/version")
-def version():
+def app_version():
     service = ArgusService()
     argus_version = service.get_version()
     return jsonify({
@@ -118,6 +117,26 @@ def release_planner_data():
     return jsonify(res)
 
 
+@bp.route("/release/<string:release_id>/versions")
+@login_required
+def release_versions(release_id: str):
+    res = {
+        "status": "ok"
+    }
+    try:
+        release_id = UUID(release_id)
+        service = ArgusService()
+        res["response"] = service.get_distinct_release_versions(release_id=release_id)
+    except Exception as exc:
+        LOGGER.error("Exception in %s", request.endpoint, exc_info=True)
+        res["status"] = "error"
+        res["response"] = {
+            "exception": exc.__class__.__name__,
+            "arguments": exc.args
+        }
+    return jsonify(res)
+
+
 @bp.route("/release/planner/comment/get/test")
 def get_planner_comment_by_test():
     res = {
@@ -327,14 +346,18 @@ def release_issues():
 
 @bp.route("/groups", methods=["GET"])
 @login_required
-def groups():
+def argus_groups():
     res = {
         "status": "ok"
     }
     try:
+        release_id = request.args.get("releaseId")
+        if not release_id:
+            raise Exception("No releaseId provided")
+
         force_all = request.args.get("all", False)
         service = ArgusService()
-        groups = service.get_groups()
+        groups = service.get_groups(UUID(release_id))
         res["response"] = [dict(g.items()) for g in groups if g.enabled or force_all]
     except Exception as exc:
         LOGGER.error("Exception in %s", request.endpoint, exc_info=True)
@@ -350,14 +373,17 @@ def groups():
 
 @bp.route("/tests", methods=["GET"])
 @login_required
-def tests():
+def argus_tests():
     res = {
         "status": "ok"
     }
     try:
+        group_id = request.args.get("groupId")
+        if not group_id:
+            raise Exception("No groupId provided")
         force_all = request.args.get("all", False)
         service = ArgusService()
-        tests = service.get_tests()
+        tests = service.get_tests(group_id=group_id)
         res["response"] = [dict(t.items()) for t in tests if t.enabled or force_all]
     except Exception as exc:
         LOGGER.error("Exception in %s", request.endpoint, exc_info=True)
@@ -371,6 +397,95 @@ def tests():
     return response
 
 
+@bp.route("/release/<string:release_id>/details", methods=["GET"])
+@login_required
+def get_release_details(release_id: str):
+    res = {
+        "status": "ok"
+    }
+    try:
+        release = ArgusRelease.get(id=UUID(release_id))
+        res["response"] = dict(release.items())
+    except Exception as exc:
+        LOGGER.error("Exception in %s", request.endpoint, exc_info=True)
+        res["status"] = "error"
+        res["response"] = {
+            "exception": exc.__class__.__name__,
+            "arguments": exc.args
+        }
+    response = jsonify(res)
+    response.cache_control.max_age = 60
+    return response
+
+
+@bp.route("/group/<string:group_id>/details", methods=["GET"])
+@login_required
+def get_group_details(group_id: str):
+    res = {
+        "status": "ok"
+    }
+    try:
+        group = ArgusReleaseGroup.get(id=UUID(group_id))
+        res["response"] = dict(group.items())
+    except Exception as exc:
+        LOGGER.error("Exception in %s", request.endpoint, exc_info=True)
+        res["status"] = "error"
+        res["response"] = {
+            "exception": exc.__class__.__name__,
+            "arguments": exc.args
+        }
+    response = jsonify(res)
+    response.cache_control.max_age = 60
+    return response
+
+
+@bp.route("/test/<string:test_id>/details", methods=["GET"])
+@login_required
+def get_test_details(test_id: str):
+    res = {
+        "status": "ok"
+    }
+    try:
+        test = ArgusReleaseGroupTest.get(id=UUID(test_id))
+        res["response"] = dict(test.items())
+    except Exception as exc:
+        LOGGER.error("Exception in %s", request.endpoint, exc_info=True)
+        res["status"] = "error"
+        res["response"] = {
+            "exception": exc.__class__.__name__,
+            "arguments": exc.args
+        }
+    response = jsonify(res)
+    response.cache_control.max_age = 60
+    return response
+
+
+@bp.route("/test-info", methods=["GET"])
+@login_required
+def test_info():
+    res = {
+        "status": "ok"
+    }
+    try:
+        test_id = request.args.get("testId")
+        if not test_id:
+            raise Exception("No testId provided")
+        service = ArgusService()
+        info = service.get_test_info(test_id=UUID(test_id))
+        res["response"] = info
+    except Exception as exc:
+        LOGGER.error("Exception in %s", request.endpoint, exc_info=True)
+        res["status"] = "error"
+        res["response"] = {
+            "exception": exc.__class__.__name__,
+            "arguments": exc.args
+        }
+
+    response = jsonify(res)
+    response.cache_control.max_age = 60
+    return response
+
+
 @bp.route("/test_run", methods=["GET"])
 @login_required
 def test_run():
@@ -530,9 +645,9 @@ def user_info():
     return jsonify(res)
 
 
-@bp.route("/release/stats", methods=["GET"])
+@bp.route("/release/stats/v2", methods=["GET"])
 @login_required
-def release_stats():
+def release_stats_v2():
     res = {
         "status": "ok"
     }
@@ -540,8 +655,10 @@ def release_stats():
         request.query_string.decode(encoding="UTF-8")
         release = request.args.get("release")
         limited = bool(int(request.args.get("limited")))
+        version = request.args.get("productVersion", None)
         force = bool(int(request.args.get("force")))
-        res["response"] = ArgusService().collect_stats(release, limited, force)
+        res["response"] = ReleaseStatsCollector(
+            release_name=release, release_version=version).collect(limited=limited, force=force)
     except Exception as exc:
         LOGGER.error("Exception in %s", request.endpoint, exc_info=True)
         LOGGER.error("Details: ", exc_info=True)
@@ -567,10 +684,10 @@ def test_runs_poll():
             limit = 10
         else:
             limit = int(limit)
-        runs = request.args.get('runs')
-        runs = runs.split(',')
+        test_id = UUID(request.args.get('testId'))
+        additional_runs = [UUID(run) for run in request.args.getlist('additionalRuns[]')]
         service = ArgusService()
-        res["response"] = service.poll_test_runs(runs=runs, limit=limit)
+        res["response"] = service.poll_test_runs(test_id=test_id, additional_runs=additional_runs, limit=limit)
     except Exception as exc:
         LOGGER.error("Exception in %s", request.endpoint, exc_info=True)
         res["status"] = "error"
@@ -681,8 +798,7 @@ def test_run_activity():
         run_id = request.args.get("runId")
         if not run_id:
             raise Exception("RunId not provided in the request")
-        else:
-            run_id = UUID(run_id)
+        run_id = UUID(run_id)
         service = ArgusService()
         res["response"] = service.fetch_run_activity(run_id=run_id)
     except Exception as exc:
@@ -756,8 +872,7 @@ def issues_get():
         key_value = request.args.get("id")
         if not key_value:
             raise Exception("Id wasn't provided in the request")
-        else:
-            key_value = UUID(key_value)
+        key_value = UUID(key_value)
         aggregate_by_issue = request.args.get("aggregateByIssue")
         aggregate_by_issue = bool(int(aggregate_by_issue)) if aggregate_by_issue else False
         service = ArgusService()
