@@ -5,6 +5,7 @@ import json
 import re
 import os
 import hashlib
+import logging
 import datetime
 from types import NoneType
 from typing import Callable
@@ -42,6 +43,8 @@ from argus.db.models import (
 )
 from argus.backend.event_processors import EVENT_PROCESSORS
 
+LOGGER = logging.getLogger(__name__)
+
 
 def first(iterable, value, key: Callable = None, predicate: Callable = None):
     for elem in iterable:
@@ -91,7 +94,7 @@ class ArgusService:
         self.runs_by_build_system_id = self.database.prepare(
             "SELECT id, test_id, group_id, release_id, build_job_url, build_id, "
             "status, start_time, end_time, heartbeat "
-            f"FROM {TestRun.table_name()} WHERE build_id = ?"
+            f"FROM {TestRun.table_name()} WHERE build_id = ? LIMIT ?"
         )
         self.jobs_by_assignee = self.database.prepare(
             "SELECT id, status, start_time, assignee, release_id, "
@@ -108,7 +111,7 @@ class ArgusService:
             f"end_time, investigation_status, heartbeat FROM {TestRun.table_name()} WHERE build_id IN ?"
         )
         self.build_id_and_url_statement = self.database.prepare(
-            f"SELECT build_id, build_job_url FROM {TestRun.table_name()} WHERE id = ?"
+            f"SELECT build_id, build_job_url, test_id FROM {TestRun.table_name()} WHERE id = ?"
         )
         self.event_insert_statement = self.database.prepare(
             'INSERT INTO argus.argus_event '
@@ -127,6 +130,9 @@ class ArgusService:
             f"UPDATE {TestRun.table_name()} SET assignee = ?"
             "WHERE build_id = ? AND start_time = ?"
         )
+        self.scylla_versions_by_release = self.database.prepare(
+            f"SELECT scylla_version FROM {TestRun.table_name()} WHERE release_id = ?"
+        )
 
     def get_version(self) -> str:
         try:
@@ -232,7 +238,7 @@ class ArgusService:
         message_stripped = strip_html_tags(message)
 
         mentions = set(mentions)
-        for potential_mention in re.findall(r"@[a-z\d](?:[a-z\d]|-(?=[a-z\d])){0,38}", message_stripped):
+        for potential_mention in re.findall(r"@[A-Za-z\d](?:[A-Za-z\d]|-(?=[A-Za-z\d])){0,38}", message_stripped):
             if user := User.exists_by_name(potential_mention.lstrip("@")):
                 mentions.add(user)
 
@@ -253,6 +259,7 @@ class ArgusService:
             params = {
                 "username": g.user.username,
                 "run_id": comment.test_run_id,
+                "test_id": run_info["test_id"],
                 "build_id": run_info["build_id"],
                 "build_number": build_number,
             }
@@ -339,12 +346,26 @@ class ArgusService:
         releases = sorted(releases, key=lambda r: r.dormant)
         return releases
 
-    def get_groups(self):
-        groups = list(ArgusReleaseGroup.all())
+    def get_groups(self, release_id: UUID) -> list[ArgusReleaseGroup]:
+        groups = list(ArgusReleaseGroup.filter(release_id=release_id).all())
         return sorted(groups, key=lambda g: g.pretty_name if g.pretty_name else g.name)
 
-    def get_tests(self):
-        return ArgusReleaseGroupTest.all()
+    def get_groups_for_release(self, release: ArgusRelease):
+        groups = ArgusReleaseGroup.filter(release_id=release.id).all()
+        return sorted(groups, key=lambda g: g.pretty_name if g.pretty_name else g.name)
+
+    def get_tests(self, group_id: UUID) -> list[ArgusReleaseGroupTest]:
+        return list(ArgusReleaseGroupTest.filter(group_id=group_id).all())
+
+    def get_test_info(self, test_id: UUID) -> dict:
+        test = ArgusReleaseGroupTest.get(id=test_id)
+        group = ArgusReleaseGroup.get(id=test.group_id)
+        release = ArgusRelease.get(id=test.release_id)
+        return {
+            "test": dict(test.items()),
+            "group": dict(group.items()),
+            "release": dict(release.items()),
+        }
 
     def get_data_for_release_dashboard(self, release_name: str):
         release = ArgusRelease.get(name=release_name)
@@ -353,161 +374,41 @@ class ArgusService:
 
         return release, release_groups, release_tests
 
-    def collect_stats(self, release_name: str, limited: bool = False, force: bool = False) -> dict:
-        response = {
-            "releases": {
+    def get_distinct_release_versions(self, release_id: UUID | str) -> list[str]:
+        release_id = UUID(release_id) if isinstance(release_id, str) else release_id
+        rows = self.session.execute(self.scylla_versions_by_release, parameters=(release_id,))
+        unique_versions = {r["scylla_version"] for r in rows if r["scylla_version"]}
 
-            }
-        }
-        group_stats_body = {
-            "total": 0,
-            **{e.value: 0 for e in TestStatus},
-            "not_run": 0,
-            "lastStatus": "unknown",
-            "lastInvestigationStatus": "unknown",
-            "hasBugReport": False,
-            "disabled": True,
-            "tests": None,
-        }
+        return sorted(list(unique_versions), reverse=True)
 
-        release = ArgusRelease.get(name=release_name)
-        if release.dormant and not force:
-            response["releases"][release.name] = {
-                "dormant": True
-            }
-            return response
-        release_tests = ArgusReleaseGroupTest.filter(release_id=release.id).all()
-        release_groups = ArgusReleaseGroup.filter(release_id=release.id).all()
-        release_groups_by_id = {group.id: group for group in release_groups}
-        tests_by_group = {}
-        for test in release_tests:
-            group = release_groups_by_id.get(test.group_id)
-            if not group:
-                continue
-            tests = tests_by_group.get(group, [])
-            tests.append(test)
-            tests_by_group[group] = tests
+    def poll_test_runs(self, test_id: UUID, additional_runs: list[UUID], limit: int = 10):
+        test: ArgusReleaseGroupTest = ArgusReleaseGroupTest.get(id=test_id)
 
-        release_stats = {
-            "total": 0,
-            **{e.value: 0 for e in TestStatus},
-            "not_run": 0,
-            "lastStatus": "unknown",
-            "lastInvestigationStatus": "unknown",
-            "hasBugReport": False,
-            "groups": {
-                group.name: dict(**group_stats_body, group_id=group.id, pretty_name=group.pretty_name) for group in release_groups
-            },
-            "tests": {},
-            "disabled": not release.enabled,
-            "perpetual": release.perpetual
-        }
-        if not release.enabled and not force:
-            release_stats["disabled"] = True
-            response["releases"][release_name] = release_stats
-            return response
-        if len(tests_by_group) == 0:
-            response["releases"][release_name] = release_stats
-            response["releases"][release_name]["empty"] = True
-            return response
+        rows = self.session.execute(
+            self.runs_by_build_system_id,
+            parameters=(test.build_system_id, limit),
+            execution_profile="read_fast"
+        ).all()
 
-        release_issues = ArgusGithubIssue.filter(release_id=release.id).all()
-        release_comments = ArgusTestRunComment.filter(release_id=release.id)
-        rows = self.session.execute(self.run_by_release_stats_statement, parameters=(release.id,)).all()
-        for group, tests in tests_by_group.items():
-            if group.enabled:
-                release_stats["groups"][group.name]["disabled"] = False
-            else:
-                continue
-            for test in tests:
-                if not test.enabled:
-                    continue
-                test_group = release_groups_by_id[test.group_id]
-                if not release_stats["groups"][test_group.name]["tests"]:
-                    release_stats["groups"][test_group.name]["tests"] = dict()
-                release_stats["total"] += 1
-                test_rows = [row for row in rows if row["build_id"] == test.build_system_id]
-                run = next(iter(test_rows)) if len(test_rows) > 0 else None
-                if not limited and run:
-                    last_runs = test_rows[:4]
-                    last_runs = [
-                        {
-                            "status": run["status"],
-                            "build_number": run["build_id"].rstrip("/").split("/")[-1],
-                            "build_job_name": run["build_id"],
-                            "start_time": run["start_time"],
-                            "assignee": run["assignee"],
-                            "issues": [dict(i.items()) for i in release_issues if i.run_id == run["id"]],
-                            "comments": [dict(i.items()) for i in release_comments if i.test_run_id == run["id"]],
-                        }
-                        for run in last_runs
-                    ]
-                    issues = last_runs[0]["issues"] if len(last_runs) > 0 else []
-                    comments = last_runs[0]["comments"] if len(last_runs) > 0 else []
+        rows_ids = [row["id"] for row in rows]
 
-                if not run:
-                    release_stats["groups"][test_group.name]["tests"][test.name] = {
-                        "name": test.name,
-                        "test_id": test.id,
-                        "status": "unknown",
-                        "group": test_group.name,
-                        "start_time": 0,
-                        "build_system_id": test.build_system_id,
-                    }
-                    release_stats["not_run"] += 1
-                    release_stats["groups"][test_group.name]["not_run"] += 1
-                    release_stats["groups"][test_group.name]["total"] += 1
-                    continue
+        for run_id in additional_runs:
+            if run_id not in rows_ids:
+                row = self.session.execute(
+                    self.runs_by_id_stmt,
+                    parameters=(UUID(run_id),),
+                    execution_profile="read_fast"
+                ).one()
+                rows.append(row)
 
-                release_stats["groups"][test_group.name]["tests"][test.name] = {
-                    "name": test.name,
-                    "test_id": test.id,
-                    "group": test_group.name,
-                    "status": run["status"],
-                    "start_time": run["start_time"],
-                    "investigation_status": run["investigation_status"],
-                    "build_system_id": test.build_system_id,
-                }
+        for row in rows:
+            try:
+                row["build_number"] = int(
+                    row["build_job_url"].rstrip("/").split("/")[-1])
+            except ValueError:
+                row["build_number"] = -1
 
-                if not limited:
-                    release_stats["hasBugReport"] = len(issues) > 0
-                    release_stats["groups"][test_group.name]["tests"][test.name]["last_runs"] = last_runs
-                    release_stats["groups"][test_group.name]["tests"][test.name]["hasBugReport"] = len(issues) > 0
-                    release_stats["groups"][test_group.name]["hasBugReport"] = len(issues) > 0
-                    release_stats["groups"][test_group.name]["tests"][test.name]["hasComments"] = len(comments) > 0
-                    release_stats["groups"][test_group.name]["hasComments"] = len(comments) > 0
-
-                release_stats["groups"][test_group.name][run["status"]] += 1
-                release_stats["groups"][test_group.name]["total"] += 1
-                release_stats["groups"][test_group.name]["lastStatus"] = run["status"]
-                release_stats["groups"][test_group.name]["lastInvestigationStatus"] = run["investigation_status"]
-                release_stats[run["status"]] += 1
-                release_stats["lastStatus"] = run["status"]
-                release_stats["lastInvestigationStatus"] = run["investigation_status"]
-
-            response["releases"][release_name] = release_stats
-
-        return response
-
-    def poll_test_runs(self, runs: list[str], limit: int = 10):
-        response = {}
-        for build_system_id in runs:
-            rows = self.session.execute(
-                self.runs_by_build_system_id,
-                parameters=(build_system_id,),
-                execution_profile="read_fast"
-            ).all()
-            rows = sorted(rows, key=lambda val: val["start_time"], reverse=True)
-            for row in rows:
-                try:
-                    row["build_number"] = int(
-                        row["build_job_url"].rstrip("/").split("/")[-1])
-                except ValueError:
-                    row["build_number"] = -1
-
-            result = rows[:limit]
-            response[build_system_id] = result
-        return response
+        return rows
 
     def poll_test_runs_single(self, runs: list[UUID]):
         rows = []
@@ -1090,9 +991,11 @@ class ArgusService:
         scheduled_groups = ArgusReleaseScheduleGroup.filter(release_id=release.id, group_id__in=group_ids).all()
         schedule_ids = {schedule.schedule_id for schedule in scheduled_groups}
 
-        today = datetime.datetime.utcnow()
         schedules = ArgusReleaseSchedule.filter(release_id=release.id, id__in=tuple(schedule_ids)).all()
-        valid_schedules = [s for s in schedules if s.period_start <= today <= s.period_end]
+
+        if release.perpetual:
+            today = datetime.datetime.utcnow()
+            valid_schedules = [s for s in schedules if s.period_start <= today <= s.period_end]
 
         response = {}
         for schedule in valid_schedules:
@@ -1117,6 +1020,10 @@ class ArgusService:
         schedule_ids = {test.schedule_id for test in scheduled_tests}
         schedules = list(ArgusReleaseSchedule.filter(release_id=release.id, id__in=tuple(schedule_ids)).all())
 
+        if release.perpetual:
+            today = datetime.datetime.utcnow()
+            schedules = list(filter(lambda s: s.period_start <= today <= s.period_end, schedules))
+
         response = {}
         for schedule in schedules:
             assignees = ArgusReleaseScheduleAssignee.filter(schedule_id=schedule.id).all()
@@ -1286,21 +1193,19 @@ class ArgusService:
                          for schedule_assignee in all_assigned_schedules]
         schedules = []
         today = datetime.datetime.utcnow()
-        last_week = today - datetime.timedelta(days=today.weekday() + 1)
         for release_id, schedule_id in schedule_keys:
             try:
                 schedule = dict(ArgusReleaseSchedule.get(release_id=release_id, id=schedule_id).items())
             except ArgusReleaseSchedule.DoesNotExist:
                 continue
-            if last_week > schedule["period_end"]:
-                continue
-            tests = ArgusReleaseScheduleTest.filter(schedule_id=schedule_id).all()
-            schedule["tests"] = [test.test_id for test in tests]
-            groups = ArgusReleaseScheduleGroup.filter(schedule_id=schedule_id).all()
-            schedule["groups"] = [group.group_id for group in groups]
-            assignees = ArgusReleaseScheduleAssignee.filter(schedule_id=schedule_id).all()
-            schedule["assignees"] = [assignee.assignee for assignee in assignees]
-            schedules.append(schedule)
+            if schedule["period_start"] <= today <= schedule["period_end"]:
+                tests = ArgusReleaseScheduleTest.filter(schedule_id=schedule_id).all()
+                schedule["tests"] = [test.test_id for test in tests]
+                groups = ArgusReleaseScheduleGroup.filter(schedule_id=schedule_id).all()
+                schedule["groups"] = [group.group_id for group in groups]
+                assignees = ArgusReleaseScheduleAssignee.filter(schedule_id=schedule_id).all()
+                schedule["assignees"] = [assignee.assignee for assignee in assignees]
+                schedules.append(schedule)
 
         return schedules
 
